package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.X509Extensions;

public class TBSRequest extends ASN1Encodable {
   private static final DERInteger V1 = new DERInteger(0);
   DERInteger version;
   GeneralName requestorName;
   ASN1Sequence requestList;
   X509Extensions requestExtensions;

   public TBSRequest(GeneralName requestorName, ASN1Sequence requestList, X509Extensions requestExtensions) {
      this.version = V1;
      this.requestorName = requestorName;
      this.requestList = requestList;
      this.requestExtensions = requestExtensions;
   }

   public TBSRequest(ASN1Sequence seq) {
      int var2 = 0;
      if (seq.getObjectAt(0) instanceof ASN1TaggedObject) {
         if (((ASN1TaggedObject)seq.getObjectAt(0)).getTagNo() == 0) {
            this.version = DERInteger.getInstance((ASN1TaggedObject)seq.getObjectAt(0), true);
            var2 = 1;
         } else {
            this.version = V1;
         }
      } else {
         this.version = V1;
      }

      if (seq.getObjectAt(var2) instanceof ASN1TaggedObject) {
         this.requestorName = GeneralName.getInstance((ASN1TaggedObject)seq.getObjectAt(var2++), true);
      }

      this.requestList = (ASN1Sequence)seq.getObjectAt(var2++);
      if (seq.size() == var2 + 1) {
         this.requestExtensions = X509Extensions.getInstance((ASN1TaggedObject)seq.getObjectAt(var2), true);
      }

   }

   public static TBSRequest getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static TBSRequest getInstance(Object obj) {
      if (obj != null && !(obj instanceof TBSRequest)) {
         if (obj instanceof ASN1Sequence) {
            return new TBSRequest((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (TBSRequest)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public GeneralName getRequestorName() {
      return this.requestorName;
   }

   public ASN1Sequence getRequestList() {
      return this.requestList;
   }

   public X509Extensions getRequestExtensions() {
      return this.requestExtensions;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERTaggedObject var2;
      if (!this.version.equals(V1)) {
         DERTaggedObject var10001 = var2 = new DERTaggedObject;
         DERInteger var3 = this.version;
         var10001.<init>(true, 0, var3);
         var1.add(var2);
      }

      GeneralName var5;
      if ((var5 = this.requestorName) != null) {
         DERTaggedObject var6;
         var6 = new DERTaggedObject.<init>(true, 1, var5);
         var1.add(var6);
      }

      var1.add(this.requestList);
      X509Extensions var4;
      if ((var4 = this.requestExtensions) != null) {
         var2 = new DERTaggedObject.<init>(true, 2, var4);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
